@@ -2,7 +2,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.16';
+$VERSION = '0.17';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -16,6 +16,10 @@ use File::Find;
 
 use constant _VERBOSE => $ENV{MI_VERBOSE} ? 1 : 0;
 
+my %ConfigureRequires = (
+    'ExtUtils::CBuilder' => 0.25, # for have_compiler()
+);
+
 my %BuildRequires = (
     'ExtUtils::ParseXS' => 2.21, # the newer, the better
 );
@@ -40,9 +44,15 @@ sub _xs_initialize{
     unless($self->{xsu_initialized}){
         $self->{xsu_initialized} = 1;
 
-        $self->requires_external_cc();
+        if(!$self->cc_available()){
+            print "This package requires a C compiler, but it's not available.\n";
+            exit(0);
+        }
+
+        $self->configure_requires(%ConfigureRequires);
         $self->build_requires(%BuildRequires);
         $self->requires(%Requires);
+
         $self->makemaker_args(OBJECT => '$(O_FILES)');
 
         if($self->_xs_debugging()){
@@ -69,6 +79,14 @@ sub _is_msvc{
     return $Config{cc} =~ /\A cl \b /xmsi;
 }
 
+sub cc_available {
+    local $@;
+    return eval{
+        require ExtUtils::CBuilder;
+        ExtUtils::CBuilder->new(quiet => 1)->have_compiler();
+    };
+}
+
 sub use_ppport{
     my($self, $dppp_version) = @_;
 
@@ -81,13 +99,18 @@ sub use_ppport{
 
     print "Writing $filename\n";
 
-    eval qq{
-        use Devel::PPPort;
-        Devel::PPPort::WriteFile(q{$filename});
-        1;
-    } or warn("Cannot create $filename: $@");
+    my $e = do{
+        local $@;
+        eval qq{
+            use Devel::PPPort;
+            Devel::PPPort::WriteFile(q{$filename});
+        };
+        $@;
+    };
+    if($e){
+         print "Cannot create $filename because: $@\n";
+    }
 
-    
     if(-e $filename){
         $self->clean_files($filename);
         $self->cc_define('-DUSE_PPPORT');
@@ -103,11 +126,11 @@ sub cc_warnings{
 
     if(_is_gcc()){
         # Note: MSVC++ doesn't support C99, so -Wdeclaration-after-statement helps ensure C89 specs.
-        $self->cc_append_to_ccflags(qw(-Wall -Wdeclaration-after-statement));
+        $self->cc_append_to_ccflags(qw(-Wall));
 
         no warnings 'numeric';
         if($Config{gccversion} >= 4.00){
-            $self->cc_append_to_ccflags('-Wextra');
+            $self->cc_append_to_ccflags('-Wextra -Wdeclaration-after-statement');
         }
         else{
             $self->cc_append_to_ccflags('-W');
@@ -498,7 +521,7 @@ Module::Install::XSUtil - Utility functions for XS modules
 
 =head1 VERSION
 
-This document describes Module::Install::XSUtil version 0.16.
+This document describes Module::Install::XSUtil version 0.17.
 
 =head1 SYNOPSIS
 
@@ -539,6 +562,12 @@ See L<XS::MRO::Compat> and L<Method::Cumulative> for example.
 
 =head1 FUNCTIONS
 
+=head2 cc_available
+
+Returns true if a C compiler is available.
+
+This uses C<ExtUtils::CBuilder>.
+
 =head2 requires_xs $module => ?$version
 
 Does C<requires()> and setup B<include paths> and B<libraries>
